"""Common configuration constants
"""

PROJECTNAME = 'cs.donedukia'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'DonEdukia': 'cs.donedukia: Add DonEdukia',
}

from Products.CMFPlone.utils import getFSVersionTuple

version = getFSVersionTuple()
IS_PLONE2 = False
IS_PLONE3 = False
IS_PLONE4 = False

if version[0] == 2:
    IS_PLONE2 = True
elif version[0] == 3:
    IS_PLONE3 = True
elif version[0] == 4:
    IS_PLONE4 = True



from zope.interface import implements, Interface

from Products.Five import BrowserView
from Products.CMFCore.utils import getToolByName

class IDonEdukiaView(Interface):
    """
    donedukia view interface
    """

    def isPlone2():
        """ Return if this is Plone 2 """

    def isPlone3():
        """ Return if this is Plone 3 """

    def isPlone4():
        """ Return if this is Plone 4 """


class DonEdukiaView(BrowserView):
    """
    donedukia browser view
    """
    implements(IDonEdukiaView)

    def __init__(self, context, request):
        self.context = context
        self.request = request

    @property
    def portal_catalog(self):
        return getToolByName(self.context, 'portal_catalog')

    @property
    def portal(self):
        return getToolByName(self.context, 'portal_url').getPortalObject()

    
    def isPlone2(self):
        from cs.donedukia.config import IS_PLONE2
        return IS_PLONE2

    def isPlone3(self):
        from cs.donedukia.config import IS_PLONE3
        return IS_PLONE3

    def isPlone4(self):
        from cs.donedukia.config import IS_PLONE4
        return IS_PLONE4
        

    




from StringIO import StringIO

from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.utils import getFSVersionTuple

def install(self):
    out = StringIO()

    tool=getToolByName(self, "portal_setup")

    if getFSVersionTuple()[:3]>=(3,0,0):
        tool.runAllImportStepsFromProfile(
            "profile-cs.donedukia:default",
            purge_old=False)
    else:
        plone_base_profileid = "profile-CMFPlone:plone"
        tool.setImportContext(plone_base_profileid)
        tool.setImportContext("profile-cs.donedukia:plone-2.5")
        tool.runAllImportSteps(purge_old=False)
        tool.setImportContext(plone_base_profileid)

    print >> out, "cs.donedukia successfully installed"

    return out.getvalue()
    



"""Definition of the DonEdukia content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder, document
from Products.ATContentTypes.content import schemata

from cs.donedukia.interfaces import IDonEdukia
from cs.donedukia.config import PROJECTNAME, IS_PLONE3, IS_PLONE4


try:
    from Products.ATContentTypes import ATCTMessageFactory as AT_
except ImportError:
    from zope.i18nmessageid import MessageFactory
    AT_ = MessageFactory('atcontenttypes')
    
DonEdukiaSchema = document.ATDocumentSchema.copy() + folder.ATFolderSchema.copy()

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

DonEdukiaSchema['title'].storage = atapi.AnnotationStorage()
DonEdukiaSchema['description'].storage = atapi.AnnotationStorage()
DonEdukiaSchema['text'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(DonEdukiaSchema, folderish=True, moveDiscussion=False)
# finalizeATCTSchema hides relatedItems for folderish items
DonEdukiaSchema['relatedItems'].widget.visible['edit'] = 'visible'


class DonEdukia(folder.ATFolder, document.ATDocument):
    """A Folderish Page"""
    implements(IDonEdukia)

    portal_type = "DonEdukia"
    schema = DonEdukiaSchema

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')
    text = atapi.ATFieldProperty('text')

    
atapi.registerType(DonEdukia, PROJECTNAME)
